# AI Context Files

The files here are intended to provide convenient context for sharing with LLMs.

The ones in this directory have been provided by developers and may be used as part of the code generation of the code in this project. The `generated` directory contains various roll-ups of the project files as a convenience for sharing with LLM tools for assistance in developing or understanding the project. The `git_collector` directory contains files that are collected from GitHub repos via the [git-collector](https://www.npmjs.com/package/git-collector) tool for the purpose of providing code and SDK documentation and examples for external libraries and tools that are used in this project.
